@@ -3,8 +3,9 @@
 # Read iso-codes data file and output a .pot file
 # 
 # Copyright (C) 2004,2005 Alastair McKinstry <mckinstry@debian.org>
+# Copyright (C) 2006,2007 Tobias Toedter <t.toedter@gmx.net>
 # Released under the GPL.
-# $Id: iso2pot.py 616 2006-08-27 09:24:06Z toddy-guest $
+# $Id: iso2pot.py 1032 2007-09-07 19:12:59Z toddy-guest $
 
 from xml.sax import make_parser, SAXException, SAXParseException
 from xml.sax.handler import feature_namespaces, ContentHandler
@@ -20,24 +21,26 @@ class printPot(ContentHandler):
 	 self.comment = comment
 	 self.ofile = ofile
 	 self.done = {}
+         self.result = []
 
 
     def startElement(self, name, attrs):
         # Get the name attributes
 	for aname in self.attrnames:
-		n = attrs.get(aname, None)
-		c = attrs.get(self.comment, None)
-		if type(n) == unicode:
-		    n = n.encode('UTF-8')
-		if type(c) == unicode:
-		    c = c.encode('UTF-8')
-		if n != None and not self.done.has_key(n):
-			self.ofile.write("\n")
-                	if c != None:
-				self.ofile.write("#. " + aname + " for " + c +  "\n")
-			self.ofile.write ("msgid \"" + n + "\"\n")
-			self.ofile.write ("msgstr \"\"\n")
-			self.done[n] = 'True'
+            n = attrs.get(aname, None)
+            c = [attrs.get(x, None) for x in self.comment]
+            if type(n) == unicode:
+                n = n.encode('UTF-8')
+            for i in range(len(c)):
+                if type(c[i]) == unicode:
+                    c[i] = c[i].encode('UTF-8')
+            if n != None:
+                if not self.done.has_key(n):
+                    self.result.append([n])
+                    self.done[n] = len(self.result)-1
+                comment_str = ", ".join([x for x in c if x is not None])
+                if comment_str:
+                    self.result[self.done[n]].append('%s for %s' % (aname, comment_str))
 
 def printHeader(ofile, iso_standard, report_bugs_to, version):
     """Print the file header
@@ -88,7 +91,7 @@ except Exception,e:
 version = "VERSION"
 report_bugs_to = "Debian iso-codes team <pkg-isocodes-devel@lists.alioth.\"\n\"debian.org>"
 fields = ["name","official_name"]
-comment = "code"
+comment = []
 ofile = sys.stdout
 
 for opt, arg in opts:
@@ -97,9 +100,11 @@ for opt, arg in opts:
     elif opt in ('-f', '--fields'):
     	fields = arg.split(',')
     elif opt in ('-c','--comments'):
-        comment = arg
+        comment.append(arg)
     elif opt in ('-o','--outfile'):
         ofile = open(arg, 'w')
+if not comment:
+    comment = ["code"]
 
 # derive the ISO standard from the first file's name
 # e.g. iso_3166_2.xml -> 3166-2
@@ -115,6 +120,8 @@ elif iso_number == '3166-2':
 	iso_desc = 'country subdivision names'
 elif iso_number == '4217':
 	iso_desc = 'currency names'
+elif iso_number == '15924':
+	iso_desc = 'script names'
 else:
 	iso_desc = ''
 
@@ -129,15 +136,21 @@ try:
     p.setContentHandler(dh)
     for infile in trail:
         p.parse(infile)
+    for x in dh.result:
+        ofile.write("\n")
+        if len(x) > 1:
+            ofile.write("#. " + ', '.join(x[1:]) +  "\n")
+        ofile.write ("msgid \"" + x[0] + "\"\n")
+        ofile.write ("msgstr \"\"\n")
 except SAXParseException, e:
     sys.stderr.write('%s:%s:%s: %s\n' % (e.getSystemId(),
                                          e.getLineNumber(),
                                          e.getColumnNumber(),
                                          e.getMessage()))
     sys.exit(1)
-except Exception, e:
-    sys.stderr.write('<unknown>: %s\n' % str(e))
-    sys.exit(1)
+#except Exception, e:
+#    sys.stderr.write('<unknown>: %s\n' % str(e))
+#    sys.exit(1)
 
 
 ofile.close()
